/*
** cmap.c -- Colormap routines
**
** These routines are architecture dependant.
**
** Copyright (C) 1992, 1993, 1994 by Michael J. Gourlay
**
** NO WARRANTEES, EXPRESS OR IMPLIED.
*/

#include "showtime.h"

/* ---------------------------------------------------------------------- */

#ifdef X11
#include <X11/Xos.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

/* X11 Colormap variables */
extern int           c_cmap;
extern Colormap      x_cmap;
extern unsigned long pixels[256];
extern int           pal1to1;
#endif

/* ---------------------------------------------------------------------- */

/* Global variables */

/* for NTSC -- saturation scalar */
extern float gm_ntsc;

/* force CGA palette (off by default) */
extern int gm_force_cga;

/* cga_color is a list of RGB values for the CGA colors */
extern unsigned char cga_color[][3];

/* cga_palette is a list of CGA colors for the lame CGA palettes */
/* Each CGA palette consists of a border color plus 3 CGA colors */
extern int cga_palette[][3];

/* ====================================================================== */

#define CGA_COLORS    16

#define CGA_BLACK     0
#define CGA_BLUE      1
#define CGA_GREEN     2
#define CGA_CYAN      3
#define CGA_RED       4
#define CGA_MAGENTA   5
#define CGA_BROWN     6    /* dark yellow */
#define CGA_WHITE     7    /* light grey */
#define CGA_GRAY      8    /* dark grey */
#define CGA_B_BLUE    9
#define CGA_B_GREEN   10
#define CGA_B_CYAN    11
#define CGA_B_RED     12
#define CGA_B_MAGENTA 13
#define CGA_B_YELLOW  14
#define CGA_B_WHITE   15

/* ---------------------------------------------------------------------- */

/* RGB color index offsets into a colormap table */
#define R 0
#define G 1
#define B 2

/* ---------------------------------------------------------------------- */

/* Colormap types */
#define GRAY   1
#define RGB332 2

/* ---------------------------------------------------------------------- */

/* RGB332MAP : approximate 24 bits of RGB with 8 bits */
/* must have already decalred [rgb]i, [rgb]b, [rgb]err as int */
#define RGB332MAP(pixel) \
{\
  /* Diffuse truncation error */\
  ri += rerr; if(ri>255) ri=255; else if(ri<0) ri=0;\
  gi += gerr; if(gi>255) gi=255; else if(gi<0) gi=0;\
  bi += berr; if(bi>255) bi=255; else if(bi<0) bi=0;\
  /* Approximate true color */\
  rb = ri & (7<<5);\
  gb = gi & (7<<5);\
  bb = bi & (3<<6);\
  pixel = (rb)|(gb>>3)|(bb>>6);\
  /* Remember truncation error */\
  rerr = ri - rgb332[pixel][R];\
  gerr = gi - rgb332[pixel][G];\
  berr = bi - rgb332[pixel][B];\
}

/* ---------------------------------------------------------------------- */

/* make_palette : create a palette */
extern int make_palette(int approx, unsigned char rgb_map[][3]);

/* ---------------------------------------------------------------------- */

/* install_cmap : install a colormap
** numvals is the number of R,G,B triples
** rgb_map is an array of R,G,B values, in the range 0-maxval
*/
extern int install_cmap(int num_vals, unsigned char rgb_map[][3], int maxval);
