/*
** image.h -- image file handling routines for ShowTime
**
** Copyright (C) by Michael J. Gourlay 1993, 1994
*/

#ifndef _IMAGE_H_INCLUDED_
#define _IMAGE_H_INCLUDED_

#include "showtime.h"

/* Image header structure */
/* All image header loaders must set num_rows, num_cols, and load_img.
*/
typedef struct image_hdr_ {
  int   image_type; /* magic number of image type */
  int   num_rows;
  int   num_cols;
  int   (*load_img)(struct image_hdr_ *, screendata_t *,  FILE *);
  void  *hdr;  /* pointer to format-specific header info */
} image_hdr_t;


/* ---------------------------------------------------------------------- */

/* Image type (magic number) for no_image */
#define NO_IMAGE_MAGIC 0

/* ====================================================================== */

extern screendata_t sd_init;

/* ====================================================================== */
/* = Image file routines = */
/* ======================= */

/* load_palette_file : read a color map from a file and install the palette */
extern int load_palette_file(char *pfn);

/* load_image : read an image from fio into image buffer sdP */
extern int load_image(screendata_t *sdP,  FILE *fio);


/* ====================================================================== */
/* = Image manipulation routines = */
/* =============================== */

/* image_hflip : horizontally flip an image.  */
extern void image_hflip(screendata_t *sdP);

/* image_vflip : vertically flip an image.  */
extern void image_vflip(screendata_t *sdP);

#endif /* _IMAGE_H_INCLUDED_ */
