/*
** pbm.h -- PBM file handling routine stuff for ShowTime
**
** Copyright (C) 1994 by Michael J. Gourlay
**
** NO WARRANTEES, EXPRESS OR IMPLIED.
*/
#ifndef _PBM_H_INCLUDED_
#define _PBM_H_INCLUDED_

#include "showtime.h"
#include "image.h"

/* ---------------------------------------------------------------------- */

/* PBMplus magic numbers */
#define PBM_MAGIC1 'P'

#define PBM_MAGIC2 '1'
#define RPBM_MAGIC2 '4'
#define PBM_FORMAT (PBM_MAGIC1 * 256 + PBM_MAGIC2)
#define RPBM_FORMAT (PBM_MAGIC1 * 256 + RPBM_MAGIC2)

#define PGM_MAGIC2 '2'
#define RPGM_MAGIC2 '5'
#define PGM_FORMAT (PBM_MAGIC1 * 256 + PGM_MAGIC2)
#define RPGM_FORMAT (PBM_MAGIC1 * 256 + RPGM_MAGIC2)

#define PPM_MAGIC2 '3'
#define RPPM_MAGIC2 '6'
#define PPM_FORMAT (PBM_MAGIC1 * 256 + PPM_MAGIC2)
#define RPPM_FORMAT (PBM_MAGIC1 * 256 + RPPM_MAGIC2)

/* ---------------------------------------------------------------------- */

typedef struct pbm_hdr_ {
  int format;
  int maxval;
  int color_approx; /* true color approximation method */
} pbm_hdr_t;

/* ---------------------------------------------------------------------- */

/* load_pnm_header : read a PNM image header and return pertinent info */
extern int load_pnm_header(image_hdr_t *ihdrP, screendata_t *sdP, FILE *fio);

/* load_ppm_palette: read a PPM file and load it as a palette.
** also install the palette
*/
extern int load_ppm_palette(FILE *fio, image_hdr_t *ihdrP);

/* load_pbm_image: read a PBM image */
extern int load_pbm_image(image_hdr_t *ihdrP, screendata_t *sdP, FILE *fio);

/* load_pgm_image: read a PGM image */
extern int load_pgm_image(image_hdr_t *ihdrP, screendata_t *sdP, FILE *fio);

/* load_ppm_image: read a PPM image
** 25mar94 MJG
**
** approx tells whether to convert to B/W or 332 RGB cmap
*/
extern int load_ppm_image(image_hdr_t *ihdrP, screendata_t *sdP, FILE *fio);

#endif /* _PBM_H_INCLUDED_ */
